import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as ComponentStories from "./async-modal.stories";

<Meta of={ComponentStories} name="Docs" />

# Async Modal

The `<ux-iws-async-modal>` component can be used to load a modal asynchronously.
You just need to specify the src-url as an attribute on the `<ux-iws-async-modal>` component.
The content will be requested only when the modal is opened.

<Canvas of={ComponentStories.Default}></Canvas>

## Async modal with variable src

If you pass a third parameter to the `data-trigger-async-modal` attribute, the `src` attribute of the async modal is set with the passed parameter.

<Canvas of={ComponentStories.VariableSrc}></Canvas>

### Triggering the modal

By setting the `opened` attribute on the `ux-iws-async-modal` element:

```
<ux-iws-async-modal name="modalName" src="/my/url" opened>...</ux-iws-async-modal>
```

By setting a `data-trigger-async-modal` attribute on any DOM element:

```
<a class="ux-button" data-trigger-async-modal="open,modalName">Open Modal</a>
```

### Async modal opened on load

By setting the attribute `opened` to true, you can ensure that the modal is opened on the initial loading.

### The content of the modal

The url that is supplied as `src` attribute should return HTML. The HTML that is returned should contain:

-   A `<ux-modal-content>` container (for the main content)
-   A `<ux-modal-footer>` container (in addition to the `ux-modal-content`)
-   Otherwise the whole HTML Response will be rendered inside the modal.

`<a>` and `<form>` Elements will be handled automatically by the modal if they dont specify a `target` attribute (for example `_blank` or `_self`). This means forms and links will be handled in a way that their response will be displayed inside the modal. (this is done in the background via an iframe)

To add a Modal-Close button to the modal content, put an Element with the following attribute in the content HTML: `data-trigger-modal="close"`. This attribute will not close all modals but only the current one.

The modal can trigger a reload of the page when the modal is closed. This can be enabled by placing this data attribute on any element inside of the async modal content: `data-modal-reload-on-close="true"`.

<Canvas of={ComponentStories.ReloadOnClose}></Canvas>

### Examples for async contents

-   <a href="./mock-data/async-modal/async-modal-2.html" target="_blank">
        Basic modal
    </a>
-   <a href="./mock-data/async-modal/async-modal.html" target="_blank">
        Modal with sections and button
    </a>

### Configuring the modal

The `ux-iws-async-modal` uses the `ux-modal` Component internally. Most attributes of `ux-modal` are also available on `ux-iws-async-modal` and will be forwarded to `ux-modal` see the properties table below.

## Developer Documentation

<Controls />
